[gtksourceview] utils: rename pango_font_description_to_css()
- From: Sébastien Wilmet <swilmet src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gtksourceview] utils: rename pango_font_description_to_css()
- Date: Sun, 24 Sep 2017 09:49:36 +0000 (UTC)
commit 939bb599f05f8f01d9852532e49a495c7715b76f
Author: Sébastien Wilmet <swilmet gnome org>
Date: Sun Sep 24 11:42:04 2017 +0200
utils: rename pango_font_description_to_css()
gtksourceview/gtksourcemap.c | 8 ++++----
gtksourceview/gtksourceview-utils.c | 2 +-
gtksourceview/gtksourceview-utils.h | 2 +-
3 files changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/gtksourceview/gtksourceview-utils.c b/gtksourceview/gtksourceview-utils.c
index 37de2d6..f8417bd 100644
--- a/gtksourceview/gtksourceview-utils.c
+++ b/gtksourceview/gtksourceview-utils.c
@@ -150,7 +150,7 @@ _gtk_source_utils_string_to_int (const gchar *str)
#define FONT_SIZE "font-size"
gchar *
-_gtk_source_pango_font_description_to_css (const PangoFontDescription *font_desc)
+_gtk_source_utils_pango_font_description_to_css (const PangoFontDescription *font_desc)
{
PangoFontMask mask;
GString *str;
diff --git a/gtksourceview/gtksourceview-utils.h b/gtksourceview/gtksourceview-utils.h
index ca65d2b..60ea248 100644
--- a/gtksourceview/gtksourceview-utils.h
+++ b/gtksourceview/gtksourceview-utils.h
@@ -38,7 +38,7 @@ G_GNUC_INTERNAL
gint _gtk_source_utils_string_to_int (const gchar *str);
G_GNUC_INTERNAL
-gchar * _gtk_source_pango_font_description_to_css (const PangoFontDescription
*font_desc);
+gchar * _gtk_source_utils_pango_font_description_to_css (const PangoFontDescription
*font_desc);
/* Note: it returns duplicated string. */
G_GNUC_INTERNAL
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/gtksourceview/gtksourcemap.c b/gtksourceview/gtksourcemap.c
index 0f9f4d0..6afb66b 100644
--- a/gtksourceview/gtksourcemap.c
+++ b/gtksourceview/gtksourcemap.c
@@ -275,9 +275,9 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
* minimap as well as the styling for the scrubber.
*
* The font is calculated from #GtkSourceMap:font-desc. We convert this
* to CSS using _gtk_source_pango_font_description_to_css(). It gets
* applied to the minimap widget via the CSS style provider which we
* attach to the view in gtk_source_map_init().
*
* The rules for calculating the style for the scrubber are as follows.
*
@@ -302,7 +302,7 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
{
gchar *css;
- css = _gtk_source_pango_font_description_to_css (priv->font_desc);
+ css = _gtk_source_utils_pango_font_description_to_css (priv->font_desc);
g_string_append_printf (gstr, "textview { %s }\n", css != NULL ? css : "");
g_free (css);
}
@@ -275,9 +275,9 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
*
* The font is calculated from #GtkSourceMap:font-desc. We convert this
- * to CSS using _gtk_source_pango_font_description_to_css(). It gets
- * applied to the minimap widget via the CSS style provider which we
- * attach to the view in gtk_source_map_init().
+ * to CSS using _gtk_source_utils_pango_font_description_to_css(). It
+ * gets applied to the minimap widget via the CSS style provider which
+ * we attach to the view in gtk_source_map_init().
*
* The rules for calculating the style for the scrubber are as follows.